@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,8 +15,8 @@
 
   MagickCore image decorate methods.
 */
-#ifndef _MAGICKCORE_DECORATE_H
-#define _MAGICKCORE_DECORATE_H
+#ifndef MAGICKCORE_DECORATE_H
+#define MAGICKCORE_DECORATE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
